Raspberry Pi Setup
===================
Start by download Raspberry Pi OS Lite from https://www.raspberrypi.org/downloads/raspberry-pi-os/. Once it is done downloading, flash the image onto a Micro SD card using a program such as `balenaEthcer <https://www.balena.io/etcher/>`_.

Mount the SD card on a computer and create an empty file named "ssh" inside the boot partition. If you only have a WiFi networking, you'll want to create a wpa_supplicant.conf file as well following `these instructions <https://www.raspberrypi.org/documentation/configuration/wireless/wireless-cli.md>`_. Otherwise, you can wait a bit and use raspi-config to do it the easy way.

Eject the card from your computer and insert the card into the Raspberry Pi.

If you didn't set up WiFi already, be sure the Raspberry Pi is plugged into your network.

Plug in power and let the Raspberry Pi boot.

Wait for a few minutes and then SSH into the Raspberry Pi using an SSH client such as PuTTY for windows or command line ssh on macOS or Linux.

Start raspi-config::

    sudo raspi-config

If you haven't already and want to enable WiFi, you can do so now by choosing Open Network Options -> Wireless LAN and follow the prompts

Be sure to set your Timezone by going to Localisation Options -> Change Timezone

You can change your password here as well, which is recommended for security.

After that you can exit the utility.


Package Updates
================
Next, you'll want to perform an update with the following commands::

    sudo apt update
    sudo apt upgrade


Install Dependencies
=====================
Install Python and other dependencies using this command::

    sudo apt install -y git python3-dev python3-pillow python3-pip libopenjp2-7 libtiff5 libatlas-base-dev


Additional Fonts
=================
Install additional fonts::

    sudo apt install -y ttf-dejavu msttcorefonts fonts-noto


RGB LED Matrix Python bindings
===============================
Install the Henner Zeller RPi RGB LED Matrix Python Bindings::

    git clone https://github.com/hzeller/rpi-rgb-led-matrix
    cd rpi-rgb-led-matrix/bindings/python
    make build-python PYTHON=$(which python3)
    sudo make install-python PYTHON=$(which python3)

Install opensign
=================
Install OpenSign via PyPI::

    sudo pip3 install opensign
